<xsl:stylesheet
     xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
     xmlns:fo="http://www.w3.org/1999/XSL/Format">

<xsl:import href="fo-toc.xsl" />
<xsl:import href="fo-tools.xsl" />

<xsl:output
	encoding="UTF-8"
/>

<!-- global variables -->

<!-- page size -->
<xsl:param name="page-height">29.7cm</xsl:param>
<xsl:param name="page-width">21.0cm</xsl:param>
<xsl:param name="margin-top">1.0cm</xsl:param>
<xsl:param name="margin-bottom">1.0cm</xsl:param>
<xsl:param name="margin-left">2.5cm</xsl:param>
<xsl:param name="margin-right">2.5cm</xsl:param>

<!-- page header and hooter extent  -->
<xsl:param name="page-header-extent">1.0cm</xsl:param>
<xsl:param name="page-footer-extent">1.0cm</xsl:param>

<!-- Company Logo -->
<xsl:param name="logo">./img/logo.jpg</xsl:param>
<xsl:param name="logo-width">1.5cm</xsl:param>

<xsl:template match ="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<!-- defines page layout -->
		<xsl:call-template name="layout-master-set"/>

		<fo:page-sequence master-name="CoverPage">
			<!-- header -->
			<xsl:call-template name="layout-master-header">
				<xsl:with-param name="title-print-in-header" select="true()"/>
				<xsl:with-param name="logo-print-in-header" select="true()"/>
			</xsl:call-template>

			<!-- footer -->
			<xsl:call-template name="layout-master-footer">
				<xsl:with-param name="page-number-print-in-footer" select="true()"/>
			</xsl:call-template>

			<fo:flow flow-name="xsl-region-body">
				<fo:block>
					<xsl:apply-templates select="/IMAP/FRONTPAGE"/>
				</fo:block>
			</fo:flow>

		</fo:page-sequence>
		
		<fo:page-sequence master-name="TOC">
			<!-- header -->
			<xsl:call-template name="layout-master-header">
				<xsl:with-param name="title-print-in-header" select="true()"/>
				<xsl:with-param name="logo-print-in-header" select="true()"/>
			</xsl:call-template>

			<fo:flow flow-name="xsl-region-body">
				<fo:block>
					<xsl:apply-templates select="/IMAP/TOC"/>
				</fo:block>
			</fo:flow>
		</fo:page-sequence>
		
		
		<fo:page-sequence master-name="normal">
			<!-- header -->
			<xsl:call-template name="layout-master-header">
				<xsl:with-param name="title-print-in-header" select="true()"/>
				<xsl:with-param name="logo-print-in-header" select="true()"/>
			</xsl:call-template>

			<!-- footer -->
			<xsl:call-template name="layout-master-footer">
				<xsl:with-param name="page-number-print-in-footer" select="true()"/>
			</xsl:call-template>

			<!-- body -->
			<fo:flow flow-name="xsl-region-body">
				<xsl:apply-templates select="/IMAP/MASTER"/>
			</fo:flow>
		</fo:page-sequence>
	</fo:root>
</xsl:template>

<xsl:template name="layout-master-set">
	<fo:layout-master-set>

		<!-- Coverpage -->			
		<fo:simple-page-master
                  	page-height="{$page-height}"
                   	page-width="{$page-width}"
                   	master-name="CoverPage">
			<fo:region-body   
				margin-top="{$margin-top}"
				margin-right="{$margin-right}"
				margin-bottom="{$margin-bottom}"
				margin-left="{$margin-left}" />
	       </fo:simple-page-master>

		<!-- Table of Contents -->			
		<fo:simple-page-master
                  	page-height="{$page-height}"
                   	page-width="{$page-width}"
                   	master-name="TOC">
			<fo:region-body   
				margin-top="{$margin-top}"
				margin-right="{$margin-right}"
				margin-bottom="{$margin-bottom}"
				margin-left="{$margin-left}" />
	       </fo:simple-page-master>

		<!-- Normal -->
		<fo:simple-page-master master-name="normal"
			page-height="{$page-height}" 
			page-width="{$page-width}"
			margin-top="{$margin-top}" 
			margin-bottom="{$margin-bottom}" 
			margin-left="{$margin-left}" 
			margin-right="{$margin-right}"
			orphans="6">
			<fo:region-body
				margin-top="{$margin-top}"
				margin-bottom="{$margin-bottom}" />
			<fo:region-before extent="{$page-header-extent}"/>
			<fo:region-after extent="{$page-footer-extent}"/>
		</fo:simple-page-master>

	</fo:layout-master-set>
</xsl:template>

<xsl:template name="layout-master-header">
	<xsl:param name="title-print-in-header" />
	<xsl:param name="logo-print-in-header" />

	<fo:static-content flow-name="xsl-region-before">
		<!-- table start -->
			<fo:table>
			<fo:table-column>
				<xsl:attribute name="column-width">
					<xsl:value-of select="concat(number(substring-before($page-width,'cm'))-number(substring-before($margin-left,'cm'))-number(substring-before($margin-right,'cm'))-number(substring-before($logo-width,'cm')),'cm')"/>
				</xsl:attribute>
			</fo:table-column> 
			<fo:table-column column-width="{$logo-width}"/>
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell >
						<fo:block>
							<xsl:if test="$title-print-in-header">
								<xsl:call-template name="addStyle">
									<xsl:with-param name="element">IMAPTITLE</xsl:with-param> 
								</xsl:call-template>
								<xsl:value-of select="IMAP/IMAPTITLE"/>
							</xsl:if>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell >
						<fo:block>
							<xsl:if test="$logo-print-in-header">
								<fo:external-graphic>
									<xsl:attribute name="src">
										<xsl:value-of select="concat('file:',$logo)" />
									</xsl:attribute>
								</fo:external-graphic> 
							</xsl:if>
						</fo:block>		
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</fo:static-content> 
</xsl:template>

<xsl:template name="layout-master-footer">
	<xsl:param name="page-number-print-in-footer"/>

	<fo:static-content flow-name="xsl-region-after">
		<fo:block>
			<fo:leader leader-pattern="rule" rule-thickness="0.5pt">
				<xsl:attribute name="leader-length">
					<xsl:value-of select="concat(number(substring-before($page-width,'cm'))-number(substring-before($margin-left,'cm'))-number(substring-before($margin-right,'cm')),'cm')"/>
				</xsl:attribute>
			</fo:leader>
		</fo:block>
      		<xsl:if test="$page-number-print-in-footer">
			<fo:block 
				text-align="end" 
				font-size="8pt" 
				font-family="serif" 
				line-height="14pt" >
				<fo:page-number/>
			</fo:block>
		</xsl:if>
	</fo:static-content> 
</xsl:template>

<xsl:template match="IMAPTITLE" />

<!-- 
	FRONTPAGE 
 -->

<xsl:template match="FRONTPAGE">
	
</xsl:template>


<!-- 
	TOC
-->

<xsl:template match="TOC">
	<!-- call template TOC in imported stylesheet fo-toc.xsl -->
 	<xsl:call-template name="TOC" />
</xsl:template>

<!-- 
	NORMAL
-->

<xsl:template match="MASTER">
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="OVERVIEWMAPTITLE">
	<xsl:if test="string-length(.) > 0">
		<fo:block>
			<xsl:call-template name="addStyle">
				<xsl:with-param name="element" select="name()"/>
			</xsl:call-template>
			<xsl:value-of select="." />
		</fo:block>				
	</xsl:if>
</xsl:template>

<xsl:template match="NAV" />

<xsl:template match="LABEL">
	<xsl:if test="string-length(.) > 0">
		<fo:block>
			<xsl:call-template name="addStyle">
				<xsl:with-param name="element" select="name()"/>
			</xsl:call-template>
			<xsl:value-of select="." />
		</fo:block>				
	</xsl:if>
</xsl:template>

<xsl:template match="PART">
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="PARTTITLE">
	<fo:block>
		<!-- id attribute to block -->
		<!-- needed to reference blocks afterwards -->	
		<xsl:if test="string-length(parent::*/@ID) > 0">
			<xsl:attribute name="id">
				<xsl:value-of select="translate(parent::*/@ID,' ','-')"/>
			</xsl:attribute>
		</xsl:if>
		
		<!-- set style -->
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element">PARTTITLE</xsl:with-param>
		</xsl:call-template>
		
		<!-- set numbering -->
		<xsl:call-template name="numbered-item">
			<xsl:with-param name="count" select="count(parent::*/ancestor::PART | parent::*/ancestor::CHAPTER | parent::*/ancestor::SECTION | parent::*/ancestor::SUBSECTION)" />
			<xsl:with-param name="node" select="parent::*" />
		</xsl:call-template>
		
		<!-- set part title -->
		<xsl:value-of select="."/>
	</fo:block>				
</xsl:template>

<xsl:template match="MAP">
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="MAPTITLE">
	<fo:block>
		<!-- set id -->
		<xsl:if test="string-length(parent::*/@ID) > 0">
			<xsl:attribute name="id">
				<xsl:value-of select="translate(parent::*/@ID,' ','-')"/>
			</xsl:attribute>
		</xsl:if>

		<!-- set style -->
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element">MAPTITLE</xsl:with-param>
		</xsl:call-template>

		<!-- set numbering -->
		<xsl:call-template name="numbered-item">
			<xsl:with-param name="count" select="count(parent::*/ancestor::PART | parent::*/ancestor::CHAPTER | parent::*/ancestor::SECTION | parent::*/ancestor::SUBSECTION)" />
			<xsl:with-param name="node" select="parent::*" />
		</xsl:call-template>
		
		<!-- set map title -->
		<xsl:value-of select="."/>
	</fo:block>
</xsl:template>
	
<xsl:template match="BLOCKLABEL">
	<xsl:if test="string-length(.) > 0">
		<fo:block>
			<xsl:call-template name="addStyle">
				<xsl:with-param name="element">BLOCKLABEL</xsl:with-param>
			</xsl:call-template>
			<xsl:value-of select="." />
		</fo:block>				
	</xsl:if>
</xsl:template>

<xsl:template match="HYPERLINK">
	<!-- Er kan maximaal één hyperlink liggen naar hetzelfde blok (dit klopt niet)-->
	
	<!--
	<fo:basic-link color="blue">
		<xsl:attribute name="internal-destination">
			<xsl:value-of select="translate(@MAPID,' ','-')" />
		</xsl:attribute>
		<xsl:value-of select="." />
	</fo:basic-link>
	-->
	<fo:inline text-decoration="underline" color="blue">
		<xsl:value-of select="." />
	</fo:inline>
</xsl:template>

<xsl:template match="P">
	<fo:block wrap-option="wrap">
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element" select="name()"/>
		</xsl:call-template>
		<xsl:apply-templates />
	</fo:block>
</xsl:template>


<xsl:template match="STEM">
<!--
	<fo:block>
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element" select="name()"/>
		</xsl:call-template>
		<xsl:value-of select="STEM"/>
	</fo:block>
-->
</xsl:template>
	

<!-- BULLIST | NUMLIST -->
<xsl:template match="BULLIST | NUMLIST">
	<xsl:if test="string-length(STEM) > 0">
		<xsl:apply-templates select="STEM" />	 		
	</xsl:if>
	<fo:list-block>
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element" select="name()"/>
		</xsl:call-template>
		<xsl:apply-templates />
	</fo:list-block>
</xsl:template>

<xsl:template match="BULLIST/ITEM">
	<fo:list-item>
		<fo:list-item-label end-indent="label-end()">
			<fo:block>
				<fo:inline font-family="Symbol">&#183;</fo:inline>
			</fo:block>
		</fo:list-item-label>
		<fo:list-item-body start-indent="body-start()">
			<fo:block>
				<xsl:value-of select="."/>
			</fo:block>
		</fo:list-item-body>
	</fo:list-item>
</xsl:template>

<xsl:template match="NUMLIST/ITEM">
	<fo:list-item>
		<fo:list-item-label end-indent="label-end()">
			<fo:block>
				<xsl:number />
			</fo:block>
		</fo:list-item-label>
		<fo:list-item-body start-indent="body-start()">
			<fo:block>
				<xsl:value-of select="."/>
			</fo:block>
		</fo:list-item-body>
	</fo:list-item>
</xsl:template>

<!-- GRAPHIC -->
<xsl:template match="GRAPHIC">
	<fo:block>
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element" select="name()"/>
		</xsl:call-template>

		<fo:external-graphic>
			<xsl:attribute name="src">
				<xsl:value-of select="concat('file:repository/illustrations/en/',@FILE)"/>
			</xsl:attribute>
		</fo:external-graphic> 
	</fo:block>
</xsl:template>

<!-- TABLE -->
<xsl:template match="TABLE">
	<fo:table>
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element" select="name()"/>
		</xsl:call-template>
		<xsl:apply-templates />
	</fo:table>
</xsl:template>

<xsl:template match="TGROUP">
	<xsl:call-template name="addColumn">
		<xsl:with-param name="cols" select="@COLS"/>
		<xsl:with-param name="colwidths" select="@COLWIDTH"/>
		<xsl:with-param name="count">1</xsl:with-param>
	</xsl:call-template>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="THEAD">
	<fo:table-header>
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element" select="name()"/>
		</xsl:call-template>
		<xsl:apply-templates/>
	</fo:table-header>
</xsl:template>

<xsl:template match="TBODY">
	<fo:table-body>
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element" select="name()"/>
		</xsl:call-template>
		<xsl:apply-templates/>
	</fo:table-body>
</xsl:template>

<xsl:template match="TDR | THR | TFR">
	<fo:table-row>
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element" select="name()"/>
		</xsl:call-template>
		<xsl:apply-templates />
	</fo:table-row>
</xsl:template>

<xsl:template match="TFOOT">
	<fo:table-footer>
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element" select="name()"/>
		</xsl:call-template>
		<xsl:apply-templates/>
	</fo:table-footer>
</xsl:template>

<xsl:template match="TD">
	<fo:table-cell>
		<fo:block>
			<xsl:call-template name="addStyle">
				<xsl:with-param name="element" select="name()"/>
			</xsl:call-template>
			<xsl:apply-templates />
		</fo:block>
	</fo:table-cell>
</xsl:template>

<xsl:template match="TH | TF">
	<fo:table-cell>
		<fo:block>
			<xsl:call-template name="addStyle">
				<xsl:with-param name="element" select="name()"/>
			</xsl:call-template>
			<xsl:value-of select="."/>
		</fo:block>
	</fo:table-cell>
</xsl:template>

<xsl:template match="B | I | U">
	<fo:table-cell>
		<fo:block>
			<xsl:call-template name="addStyle">
				<xsl:with-param name="element" select="name()"/>
			</xsl:call-template>
			<xsl:value-of select="."/>
		</fo:block>
	</fo:table-cell>
</xsl:template>

</xsl:stylesheet>
