<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

<xsl:import href="fo-tools.xsl" />

<!-- Globale variables -->
<xsl:param name="indent" select="false()" />
<xsl:param name="number" select="true()" />
<xsl:param name="levels">3</xsl:param>

<!-- Width of TOC table-->
<xsl:param name="title-width">14cm</xsl:param>
<xsl:param name="page-number-width">3cm</xsl:param>

<xsl:template match="TOCTITLE">
	<fo:block>
		<xsl:call-template name="addStyle">
			<xsl:with-param name="element">TOCTITLE</xsl:with-param>
		</xsl:call-template>
		<xsl:value-of select="." />
	</fo:block>
</xsl:template>
	
<xsl:template name="TOC" >
	<xsl:apply-templates select="TOCTITLE"  />

	<fo:table>
		<fo:table-column column-width="{$title-width}" />
		<fo:table-column column-width="{$page-number-width}" />
		<fo:table-body>

		<xsl:for-each select="//node()">
	
			<xsl:variable name="level">
				<xsl:value-of select='count(ancestor::PART | ancestor::CHAPTER | ancestor::SECTION | ancestor::SUBSECTION)'/>
			</xsl:variable>
	
			<xsl:if test="name(.) = 'PART' or name(.) = 'CHAPTER' or name(.) = 'SECTION' or name(.) = 'SUBSECTION' or name(.) = 'MAP' or name(.) = 'LINK' ">
				<xsl:if test="$level + 1 &lt;= $levels">
					<fo:table-row>
						<fo:table-cell>
							<fo:block>
								<!-- set style -->
								<xsl:call-template name="addStyle">
									<xsl:with-param name="element">
										<xsl:value-of select="concat('TOCLEVEL',$level)"/>
									</xsl:with-param>
								</xsl:call-template>

								<!-- set indentation -->
								<xsl:if test="$indent">
									<xsl:call-template name="indent">
										<xsl:with-param name="count" select="$level" />
									</xsl:call-template>
								</xsl:if>
									
								<!-- set numbering -->
								<xsl:if test="$number">
									<xsl:call-template name="numbered-item">
										<xsl:with-param name="count" select="$level" />
										<xsl:with-param name="node" select="." />
									</xsl:call-template>
								</xsl:if>
							
								<!-- set title -->
						       	<xsl:choose>
									<xsl:when test='string-length(NAV) > 0'>
										<xsl:value-of select="NAV"/>
									</xsl:when>
									<xsl:when test='string-length(PARTTITLE) > 0'>
										<xsl:value-of select="PARTTITLE"/>
									</xsl:when>
									<xsl:when test='string-length(CHAPTERTITLE) > 0'>
										<xsl:value-of select="CHAPTERTITLE"/>
									</xsl:when>
									<xsl:when test='string-length(SECTIONTITLE) > 0'>
										<xsl:value-of select="SECTIONTITLE"/>
									</xsl:when>
									<xsl:when test='string-length(SUBSECTIONTITLE) > 0'>
										<xsl:value-of select="SUBSECTIONTITLE"/>
									</xsl:when>
									<xsl:when test='string-length(MAPTITLE) > 0'>
										<xsl:value-of select="MAPTITLE"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select='name()'/>
										<xsl:value-of select='@NUMBER'/>
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>	
						</fo:table-cell>
							
						<!-- set pagenumber -->
						<fo:table-cell>
							<fo:block>
								<!-- set style -->
								<xsl:call-template name="addStyle">
									<xsl:with-param name="element">
										<xsl:value-of select="concat('TOCLEVEL',$level)"/>
									</xsl:with-param>
								</xsl:call-template>
								<xsl:choose>
									<xsl:when test="@ID">
										<fo:page-number-citation>
											<xsl:attribute name="ref-id">
												<xsl:value-of select="translate(@ID,' ','-')"/>
											</xsl:attribute>
										</fo:page-number-citation>
									</xsl:when>
									<xsl:otherwise>#IDREF?</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						
					</fo:table-row>
				</xsl:if>	
			</xsl:if>	
		</xsl:for-each>
		</fo:table-body>
	</fo:table>
</xsl:template>

<!--
	indent
	=====
-->
<xsl:template name="indent">
	<xsl:param name="count"/>
	<xsl:if test="$count != 0">
		<fo:external-graphic src="file:./img/space.jpg"/>
		<xsl:call-template name="indent">
			<xsl:with-param name="count" select="$count - 1"/>
		</xsl:call-template>
	</xsl:if>
</xsl:template>


</xsl:stylesheet>
