<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

<xsl:import href="trisoft-string.xsl" />

<xsl:param name='styledefinition'>fo-styles.xml</xsl:param>

<!-- 	
	=========
	addColumn 
	=========
	add the right number of colums and calculates the width of each column	

	input parameters:
	* cols		: the number of columns that have to be added
	* colwidths	: the column width of each column concatenated by a space
	* count		: the number of the column that is added
-->

<xsl:template name="addColumn">
	<xsl:param name="cols"/>
	<xsl:param name="colwidths"/>
	<xsl:param name="count"/>
	
	<xsl:if test="$cols &gt; 0">
		<!-- add the column -->
		<fo:table-column>
			<xsl:attribute name="column-width">
				<!-- insert the right column width -->
				<xsl:call-template name="tokenizer">
					<xsl:with-param name="token_nr" select="$count"/>
					<xsl:with-param name="string" select="$colwidths"/>
					<xsl:with-param name="delimiter"><xsl:text> </xsl:text></xsl:with-param>
				</xsl:call-template>
			</xsl:attribute>
		</fo:table-column> 

		<!-- add the next column (recursive call) -->
		<xsl:call-template name="addColumn">
			<xsl:with-param name="cols" select="$cols - 1"/>
			<xsl:with-param name="colwidths" select="$colwidths"/>
			<xsl:with-param name="count" select="$count + 1"/>
		</xsl:call-template>
	</xsl:if>

</xsl:template>


<!--
	numbered-item
	============
	input parameters
	* count: the level of the node
	* node: the current node of which the numbering has to be calculated
-->

<xsl:template name="numbered-item">
	<xsl:param name="count"/>
	<xsl:param name="node"/>
	<xsl:variable name="result-string">
		<xsl:call-template name="number-item">
			<xsl:with-param name="count" select="$count"/>
			<xsl:with-param name="node" select="$node"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- call template reverse-string from imported trisoft-string.xsl -->
	<xsl:call-template name="reverse-string">
		<xsl:with-param name="string" select="$result-string"/>
		<xsl:with-param name="length" select="string-length($result-string)" />
	</xsl:call-template>
	<xsl:text> </xsl:text>
</xsl:template>

<!--
	number-item
	==========
	the template number item results in a reversed numbering
	.1.2 is the reversed string of  2.1.
-->
<xsl:template name="number-item">
	<xsl:param name="count"/>
	<xsl:param name="node"/>
	<xsl:if test="$count >= 0">
		<xsl:text>.</xsl:text>
		<xsl:value-of select="count($node/preceding-sibling::*[name()=name($node) or name()='MAP'])+1"/>
		<xsl:call-template name="number-item">
			<xsl:with-param name="count" select="$count - 1" />
			<xsl:with-param name="node" select="$node/parent::*" />
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<!-- 
	addStyle
	=======
-->
<xsl:template name="addStyle">
	<xsl:param name="element"/>
	<!-- if the element exists in the styledefinition add the appropriate styles -->
	<xsl:if test="count(document($styledefinition)//STYLE[@xml-tag = $element]) > 0">
		<xsl:for-each select="document($styledefinition)//STYLE[@xml-tag = $element]/@*">
			<xsl:if test="name() != 'xml-tag'">
				<xsl:attribute name="{name()}">
					<xsl:value-of select="."/>
				</xsl:attribute>
			</xsl:if>
		</xsl:for-each>
	</xsl:if>
</xsl:template>

</xsl:stylesheet>
